pub fn parse_futures_account_update(
msg: &BinanceFuturesAccountUpdateMsg,
account_id: AccountId,
ts_init: UnixNanos,
) -> Option<AccountState>Expand description
Converts a Binance Futures account update to a Nautilus account state.
pub fn parse_futures_account_update(
msg: &BinanceFuturesAccountUpdateMsg,
account_id: AccountId,
ts_init: UnixNanos,
) -> Option<AccountState>Converts a Binance Futures account update to a Nautilus account state.